@@ -1,10 +1,10 @@
-from solaredge_setapp import maintenance
-from solaredge_setapp import information
-from solaredge_setapp import status
-
 import enum
 import itertools
 
+import solaredge_setapp.information
+import solaredge_setapp.maintenance
+import solaredge_setapp.status
+
 
 TARGET_VERSION = "1.4.10"
 
@@ -370,4 +370,48 @@ class PairingStatusStage(enum.Enum):
 class CommTestStatus(enum.Enum):
     FAILED = 0
     PASSED = 1
-    NOT_TESTED = 2
\ No newline at end of file
+    NOT_TESTED = 2
+
+
+class ServerChannelMethod(enum.Enum):
+    MANUAL_SELECT = 0
+    AUTO_SELECT = 1
+
+
+class OperationMode(enum.Enum):
+    INV_OPER_MODE_ON_GRID = 0
+    INV_OPER_MODE_STORAGE_OFF_GRID = 1
+    INV_OPER_MODE_DG_OFF_GRID = 2
+
+
+class LanNetStatus(enum.Enum):
+    LAN_UNKNOWN = 0
+
+
+class WifiNetStatus(enum.Enum):
+    WIFI_UNKNOWN = 0
+
+
+class CellNetStatus(enum.Enum):
+    CELL_UNKNOWN = 0
+    CELL_NOT_DETECTED = 1
+    CELL_DETECTION_IN_PROGRESS = 2
+    CELL_INIT_MODULE = 3
+    CELL_NO_SIM_CARD = 4
+    CELL_MISSING_PIN = 5
+    CELL_SIM_NOT_REGISTERED = 6
+    CELL_MODEM_NOT_ACTIVATED = 7
+    CELL_MISSING_APN = 8
+    CELL_NO_SIGNAL = 9
+    CELL_NO_COMM_WITH_MODULE = 10
+    CELL_ESTABLISHING_INTERNET_CONNECTION = 11
+    CELL_NO_INTERNET_CONNECTION = 12
+    CELL_NO_TELEM_PLAN_SELECT = 13
+    CELL_ACTIVATING_TELEM_PLAN = 14
+    CELL_ACTIVATING_ERROR_NO_RESPONSE = 15
+    CELL_ACTIVATING_ERROR_UNIDENTIFIED_NUMBER = 16
+    CELL_ACTIVATING_ERROR_SMS_BLOCKED = 17
+    CELL_ACTIVATING_ERROR_NO_SMS = 18
+    CELL_ACTIVATING_ERROR = 19
+    CELL_CONNECTING_TO_SERVER = 20
+    CELL_CONNECTED = 21
